@@ -116,7 +116,7 @@ QString nodeTypeToString(int type)
 
 // ------------------------------------------------------------------------
 AST::AST()
-    : m_nodeType(NodeType_Generic), m_parent(0),
+    : m_nodeType(NodeType_Generic), m_parent(nullptr),
       m_startLine(0), m_startColumn(0),
       m_endLine(0), m_endColumn(0)
 {
