@@ -177,7 +177,11 @@ QStringList getMethodTokens(QString text)
 
 const QString indentString(KTextEditor::Document *document)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KTextEditor::ConfigInterface *iface = qobject_cast<KTextEditor::ConfigInterface *>(document);
+#else
+    KTextEditor::Document *iface  = document;
+#endif
     if (!iface)
         return QStringLiteral("    ");
     if (iface->configValue(QStringLiteral("replace-tabs")).toBool()) {
