@@ -82,7 +82,7 @@ AbstractType::Ptr TypeBuilder::parseType(QString type, AstNode* node)
         }
         if (type.contains('|')) {
             QList<AbstractType::Ptr> types;
-            foreach (const QString& t, type.split('|')) {
+            for(const QString& t : type.split('|')) {
                 AbstractType::Ptr subType = parseType(t, node);
                 if (!(IntegralType::Ptr::dynamicCast(subType) && IntegralType::Ptr::staticCast(subType)->dataType() == IntegralType::TypeMixed)) {
                     types << parseType(t, node);
@@ -90,7 +90,7 @@ AbstractType::Ptr TypeBuilder::parseType(QString type, AstNode* node)
             }
             if (!type.isEmpty()) {
                 UnsureType::Ptr ret(new UnsureType());
-                foreach (const AbstractType::Ptr& t, types) {
+                for(const AbstractType::Ptr& t : types) {
                     ret->addType(t->indexed());
                 }
                 //qCDebug(DUCHAIN) << type << ret->toString();
@@ -130,7 +130,7 @@ QStringList findInDocComment(const QString &docComment, const QString &docCommen
     // old code was something like this:
     /*
     if (!docComment.isEmpty()) {
-        QRegExp rx("\\*\\s+@param\\s([^\\s]*)");
+        QRegularExpression rx("\\*\\s+@param\\s([^\\s]*)");
         int pos = 0;
         while ((pos = rx.indexIn(docComment, pos)) != -1) {
             ret << parseType(rx.cap(1), node);
@@ -219,7 +219,7 @@ QList<AbstractType::Ptr> TypeBuilder::parseDocCommentParams(AstNode* node)
         const QStringList& matches = findInDocComment(docComment, QStringLiteral("param"), false);
         if ( !matches.isEmpty() ) {
             ret.reserve(matches.size());
-            foreach ( const QString& type, matches ) {
+            for( const QString& type : matches ) {
                 ret << parseType(type, node);
             }
         }
@@ -495,7 +495,7 @@ void TypeBuilder::visitStatement(StatementAst* node)
         }
     }
 
-    AstNode *foreachNode = 0;
+    AstNode  *foreachNode = nullptr;
     if (node->foreachVar) {
         foreachNode = node->foreachVar;
     } else if (node->foreachExpr) {
@@ -529,7 +529,7 @@ void TypeBuilder::visitStatement(StatementAst* node)
                     static const QualifiedIdentifier currentQId(QStringLiteral("current"));
                     auto classContext = classDec->internalContext();
                     if (classContext) {
-                        foreach (Declaration *d, classContext->findDeclarations(currentQId)) {
+                        for(Declaration *d : classContext->findDeclarations(currentQId)) {
                             if (!dynamic_cast<ClassMethodDeclaration*>(d)) continue;
                             Q_ASSERT(d->type<FunctionType>());
                             injectType(d->type<FunctionType>()->returnType());
