@@ -1,7 +1,7 @@
-/**
- * file comment
- * multi line
- */
+/*
+    file comment
+    multi line
+*/
 
 // class comments_file_variant1 single line comment
 class comments_file_variant1 {};
