@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2002-2008                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef UMLCLIPBOARD_H
 #define UMLCLIPBOARD_H
@@ -27,7 +22,7 @@ class QMimeData;
  *
  * @short Clipboard management class
  * @author Gustavo Madrigal
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class UMLClipboard : public QObject
 {
@@ -60,8 +55,6 @@ private:
     bool pasteClip4(const QMimeData* data);
     bool pasteClip5(const QMimeData* data);
 
-    bool checkPasteWidgets(UMLWidgetList & widgetList);
-
     UMLObjectList m_ObjectList;
     UMLListViewItemList m_ItemList;
     UMLWidgetList m_WidgetList;
@@ -72,7 +65,7 @@ private:
 private:
     void addRelatedWidgets();
 
-    void fillObjectListForWidgets(UMLWidgetList& widgets);
+    void fillObjectListForWidgets(const UMLWidgetList& widgets);
 
     bool fillSelectionLists(UMLListViewItemList& selectedItems);
 
