@@ -8,12 +8,12 @@
 
 // local includes
 #include "associationwidget.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "cmds.h"
 #define DBG_SRC QStringLiteral("UMLDragData")
 #include "debug_utils.h"
 #include "floatingtextwidget.h"
-#include "folder.h"
+#include "umlfolder.h"
 #include "idchangelog.h"
 #include "model_utils.h"
 #include "object_factory.h"
@@ -22,7 +22,7 @@
 #include "preconditionwidget.h"
 #include "messagewidget.h"
 #include "uniqueid.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umllistview.h"
 #include "umllistviewitem.h"
