@@ -10,7 +10,7 @@
 #include "debug_utils.h"
 #include "umlscene.h"
 #include "umlwidget.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 // kde includes
 #include <KLocalizedString>
