@@ -11,13 +11,13 @@
 // local includes
 #include "codegenerator.h"
 #include "debug_utils.h"
-#include "package.h"
+#include "umlpackage.h"
 #include "umldoc.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // qt includes
 #include <QDateTime>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QXmlStreamWriter>
 
 /**
@@ -25,7 +25,7 @@
  */
 CodeDocument::CodeDocument () : CodeGenObjectWithTextBlocks(this),
     m_lastTagIndex(0), m_filename(QString()), m_fileExtension(QString()),
-    m_ID(QString()), m_pathName(QString()), m_package(0), m_writeOutCode(true)
+    m_ID(QString()), m_pathName(QString()), m_package(nullptr), m_writeOutCode(true)
 {
     setHeader(new CodeComment(this));
     //  m_dialog = new CodeDocumentDialog();
@@ -102,11 +102,11 @@ QString CodeDocument::getPath () const
     path = path.simplified();
 
     // Replace all blanks with underscore
-    path.replace(QRegExp(QStringLiteral(" ")), QStringLiteral("_"));
+    path.replace(QRegularExpression(QStringLiteral(" ")), QStringLiteral("_"));
 
     // this allows multiple directory paths (ala Java, some other languages)
     // in from the package specification
-    path.replace(QRegExp(QStringLiteral("\\.")), QStringLiteral("/"));
+    path.replace(QRegularExpression(QStringLiteral("\\.")), QStringLiteral("/"));
     // Simple hack!.. but this is more or less language
     // dependent and should probably be commented out.
     // Still, as a general default it may be useful -b.t.
@@ -223,7 +223,7 @@ bool CodeDocument::insertTextBlock(TextBlock * newBlock, TextBlock * existingBlo
     if (index < 0)
     {
         // may be hiding in child hierarchical codeblock
-        foreach (TextBlock* tb, m_textblockVector)
+        for(TextBlock* tb: m_textblockVector)
         {
             HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(tb);
             if (hb && hb->insertTextBlock(newBlock, existingBlock, after))
@@ -278,10 +278,10 @@ void CodeDocument::updateHeader ()
     //try to find a heading file (license, comments, etc) then extract its text
     QString headingText = UMLApp::app()->commonPolicy()->getHeadingFile(getFileExtension());
 
-    headingText.replace(QRegExp(QStringLiteral("%filename%")), getFileName()+getFileExtension());
-    headingText.replace(QRegExp(QStringLiteral("%filepath%")), getPath());
-    headingText.replace(QRegExp(QStringLiteral("%time%")), QTime::currentTime().toString());
-    headingText.replace(QRegExp(QStringLiteral("%date%")), QDate::currentDate().toString());
+    headingText.replace(QRegularExpression(QStringLiteral("%filename%")), getFileName()+getFileExtension());
+    headingText.replace(QRegularExpression(QStringLiteral("%filepath%")), getPath());
+    headingText.replace(QRegularExpression(QStringLiteral("%time%")), QTime::currentTime().toString());
+    headingText.replace(QRegularExpression(QStringLiteral("%date%")), QDate::currentDate().toString());
 
     getHeader()->setText(headingText);
 
@@ -309,7 +309,7 @@ QString CodeDocument::toString () const
 
     // comments, import, package codeblocks go next
     TextBlockList * items = getTextBlockList();
-    foreach (TextBlock* c, *items)
+    for (TextBlock* c: *items)
     {
         if (c->getWriteOutText()) {
             QString str = c->toString();
@@ -390,13 +390,13 @@ void CodeDocument::setAttributesFromNode (QDomElement & root)
     QString pkgStr = root.attribute(QStringLiteral("package"));
     if (!pkgStr.isEmpty() && pkgStr != QStringLiteral("-1")) {
         UMLDoc *umldoc = UMLApp::app()->document();
-        if (pkgStr.contains(QRegExp(QStringLiteral("\\D")))) {
+        if (pkgStr.contains(QRegularExpression(QStringLiteral("\\D")))) {
             // suspecting pre-1.5.3 file format where the package name was
             // saved instead of the package ID.
             UMLObject *o = umldoc->findUMLObject(pkgStr);
             m_package = o->asUMLPackage();
         }
-        if (m_package == 0) {
+        if (m_package == nullptr) {
             UMLObject *o = umldoc->findObjectById(Uml::ID::fromString(pkgStr));
             m_package = o->asUMLPackage();
         }
@@ -506,7 +506,7 @@ TextBlock * CodeDocument::findTextBlockByTag(const QString &tag, bool descendInt
         if (m_childTextBlockTagMap.contains(tag))
             return m_childTextBlockTagMap[tag];
 
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -516,7 +516,7 @@ TextBlock * CodeDocument::findTextBlockByTag(const QString &tag, bool descendInt
 TextBlock * CodeDocument::findCodeClassFieldTextBlockByTag (const QString &tag)
 {
     logWarn1("Called findCodeClassFieldMethodByTag(%1) for a regular CodeDocument", tag);
-    return 0;
+    return nullptr;
 }
 
 QDebug operator<<(QDebug os, const CodeDocument& obj)
