@@ -13,14 +13,14 @@
 #include "overwritedialog.h"
 #include "codeviewerdialog.h"
 #include "simplecodegenerator.h"
-#include "attribute.h"
-#include "association.h"
-#include "classifier.h"
+#include "umlattribute.h"
+#include "umlassociation.h"
+#include "umlclassifier.h"
 #include "classifiercodedocument.h"
 #include "codedocument.h"
 #include "codegenerationpolicy.h"
-#include "operation.h"
-#include "uml.h"
+#include "umloperation.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlattributelist.h"
@@ -251,7 +251,7 @@ void CodeGenerator::saveToXMI(QXmlStreamWriter& writer)
         UMLClassifierList concepts = m_document->classesAndInterfaces();
         for(UMLClassifier *c : concepts) {
             uIgnoreZeroPointer(c);
-            UMLOperationList operations = c->getOpList();
+            UMLOperationList operations = c->getOperationsList();
             for(UMLOperation *op : operations) {
                 // save the source code
                 QString code = op->getSourceCode();
@@ -656,7 +656,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
     }
 
     //operations
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     for(UMLOperation *op : opl) {
         temp = nullptr;
         //check return value
@@ -665,7 +665,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
             cList.append(temp);
         }
         //check parameters
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
         for(UMLAttribute *at : atl) {
             temp = (UMLClassifier*)at->getType();
             if (temp && !temp->isUMLDatatype() && !cList.count(temp)) {
