@@ -9,14 +9,14 @@
 #include "codeparameter.h"
 
 // local includes
-#include "association.h"
-#include "attribute.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
 #include "classifiercodedocument.h"
 #include "debug_utils.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "codegenfactory.h"
 
 // qt/kde includes
