@@ -18,11 +18,11 @@
 #include "cppheadercodeclassfielddeclarationblock.h"
 #include "debug_utils.h"
 #include "umlpackagelist.h"
-#include "package.h"
+#include "umlpackage.h"
 #include "umlclassifierlistitemlist.h"
-#include "classifierlistitem.h"
-#include "enum.h"
-#include "uml.h"
+#include "umlclassifierlistitem.h"
+#include "umlenum.h"
+#include "umlapp.h"
 
 // qt includes
 
@@ -367,7 +367,7 @@ void CPPHeaderCodeDocument::updateContent()
     CodeClassFieldList privCompositionClassFields = getSpecificClassFields (CodeClassField::Composition, Uml::Visibility::Private);
 
     bool hasOperationMethods = false;
-    UMLOperationList list = c->getOpList();
+    UMLOperationList list = c->getOperationsList();
     hasOperationMethods = ! list.isEmpty();
 
     bool hasNamespace = false;
