@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef CPPMAKECODEDOCUMENT_H
@@ -36,9 +36,9 @@ public:
     /**
      * @return  QString
      */
-    QString toString ();
+    QString toString () const;
 
-    QString getPath ();
+    QString getPath () const;
 
     void updateContent();
 
