@@ -11,7 +11,7 @@
 #include "cppcodegenerationpolicy.h"
 #include "cppsourcecodedocument.h"
 #include "cppcodedocumentation.h"
-#include "uml.h"
+#include "umlapp.h"
 
 CPPSourceCodeOperation::CPPSourceCodeOperation(CPPSourceCodeDocument * doc, UMLOperation *parent, const QString & body, const QString & comment)
         : CodeOperation (doc, parent, body, comment)
@@ -63,7 +63,7 @@ void CPPSourceCodeOperation::updateMethodDeclaration()
     QString className = CodeGenerator::cleanName(c->name());
 
     // assemble parameters
-    UMLAttributeList list = getParentOperation()->getParmList();
+    UMLAttributeList list = getParentOperation()->getParameterList();
     int nrofParam = list.count();
     int paramNum = 0;
     for(UMLAttribute* parm : list) {
