@@ -11,21 +11,21 @@
 #include "cppwriter.h"
 
 // app includes
-#include "association.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlclassifier.h"
 #include "codegen_utils.h"
-#include "datatype.h"
+#include "umldatatype.h"
 #include "debug_utils.h"
 #include "model_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
-#include "operation.h"
-#include "template.h"
+#include "umloperation.h"
+#include "umltemplate.h"
 #include "umltemplatelist.h"
 #include "umlclassifierlistitemlist.h"
-#include "classifierlistitem.h"
+#include "umlclassifierlistitem.h"
 #include "codegenerationpolicy.h"
-#include "enumliteral.h"
+#include "umlenumliteral.h"
 
 // qt includes
 #include <QFile>
@@ -1200,7 +1200,7 @@ void CppWriter::writeOperations(UMLClassifier *c, bool isHeaderMethod,
     UMLOperationList oplist;
 
     //sort operations by scope first and see if there are abstract methods
-    UMLOperationList inputlist = c->getOpList();
+    UMLOperationList inputlist = c->getOperationsList();
     for (UMLOperation* op : inputlist) {
         if (op->visibility() == permitScope) {
             oplist.append(op);
@@ -1235,7 +1235,7 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
     for (UMLOperation* op : oplist) {
         QString doc;  // buffer for documentation
         QString methodReturnType;
-        UMLAttributeList atl = op->getParmList();  // method parameters
+        UMLAttributeList atl = op->getParameterList();  // method parameters
 
         if (op->isConstructorOperation()) {
             if (generateEmptyConstructors && atl.count() == 0)
