@@ -14,10 +14,10 @@
 #include "dclassdeclarationblock.h"
 #include "dcodeclassfielddeclarationblock.h"
 #include "codegen_utils.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "codegenerationpolicy.h"
 #include "debug_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // qt includes
 #include <QRegularExpression>
@@ -310,7 +310,7 @@ void DClassifierCodeDocument::updateContent()
     bool isInterface = parentIsInterface();
     bool hasOperationMethods = false;
 
-    UMLOperationList list = c->getOpList();
+    UMLOperationList list = c->getOperationsList();
     hasOperationMethods = ! list.isEmpty();
 
     QString endLine = commonPolicy->getNewLineEndingChars(); // a shortcut..so we don't have to call this all the time
