@@ -9,13 +9,13 @@
 #include "dcodeclassfield.h"
 
 // local includes
-#include "attribute.h"
+#include "umlattribute.h"
 #include "dcodecomment.h"
 #include "dcodegenerator.h"
 #include "debug_utils.h"
 #include "umlobject.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // #include "dcodeaccessormethod.h"
 #include "dclassifiercodedocument.h"
