@@ -9,7 +9,7 @@
 #include "dcodegenerationpolicypage.h"
 
 // app includes
-#include "uml.h"
+#include "umlapp.h"
 
 // kde includes
 #include <KLocalizedString>
