@@ -9,15 +9,15 @@
 #include "dwriter.h"
 
 // app includes
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "codegen_utils.h"
 #include "debug_utils.h"
-#include "operation.h"
-#include "template.h"
+#include "umloperation.h"
+#include "umltemplate.h"
 #include "umldoc.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 #include "umltemplatelist.h"
 
 // qt includes
@@ -204,7 +204,7 @@ void DWriter::writeClass(UMLClassifier *c)
     bool hasAssociations = aggregations.count() + associations.count() + compositions.count() + uniAssociations.count() > 0;
     bool hasAttributes = atl.count() > 0;
     bool hasAccessorMethods = hasAttributes || hasAssociations;
-    bool hasOperationMethods = c->getOpList().count() > 0;
+    bool hasOperationMethods = c->getOperationsList().count() > 0;
 
     // ATTRIBUTES
     //
@@ -766,8 +766,8 @@ bool DWriter::compareDMethod(UMLOperation *op1, UMLOperation *op2)
         return true;
     if (op1->name() != op2->name())
         return false;
-    UMLAttributeList atl1 = op1->getParmList();
-    UMLAttributeList atl2 = op2->getParmList();
+    UMLAttributeList atl1 = op1->getParameterList();
+    UMLAttributeList atl2 = op2->getParameterList();
     if (atl1.count() != atl2.count())
         return false;
 
@@ -796,7 +796,7 @@ void DWriter::getSuperImplementedOperations(UMLClassifier *c, UMLOperationList &
 
     for(UMLClassifier* classifier : superClasses) {
         getSuperImplementedOperations(classifier, yetImplementedOpList, toBeImplementedOpList, (classifier->isInterface() && noClassInPath));
-        UMLOperationList opl = classifier->getOpList();
+        UMLOperationList opl = classifier->getOperationsList();
         for(UMLOperation* op : opl) {
             if (classifier->isInterface() && noClassInPath) {
                 if (!DWriter::dMethodInList(op, toBeImplementedOpList))
@@ -829,7 +829,7 @@ void DWriter::writeOperations(UMLClassifier *c, QTextStream &d)
     UMLOperationList oppub, opprot, oppriv;
 
     //sort operations by scope first and see if there are abstract methods
-    opl = c->getOpList();
+    opl = c->getOperationsList();
     if (! c->isInterface()) {
         getInterfacesOperationsToBeImplemented(c, opl);
     }
@@ -901,7 +901,7 @@ void DWriter::writeOperations(UMLOperationList &oplist, QTextStream &d)
 
         str += methodReturnType + QLatin1Char(' ') + cleanName(op->name()) + QLatin1Char('(');
 
-        atl = op->getParmList();
+        atl = op->getParameterList();
         int i = atl.count();
         int j = 0;
         for (UMLAttributeListIt atlIt(atl); atlIt.hasNext();  ++j) {
