@@ -23,10 +23,10 @@
 #include "javaclassdeclarationblock.h"
 #include "javacodeclassfielddeclarationblock.h"
 #include "codegen_utils.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "codegenerationpolicy.h"
 #include "debug_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // qt includes
 #include <QRegularExpression>
@@ -300,7 +300,7 @@ void JavaClassifierCodeDocument::updateContent()
 
     bool isInterface = parentIsInterface();
     bool hasOperationMethods = false;
-    UMLOperationList list = c->getOpList();
+    UMLOperationList list = c->getOperationsList();
     hasOperationMethods = ! list.isEmpty();
 
     QString endLine = commonPolicy->getNewLineEndingChars(); // a shortcut..so we don't have to call this all the time
