@@ -9,14 +9,14 @@
 #include "javacodeaccessormethod.h"
 
 // local includes
-#include "attribute.h"
+#include "umlattribute.h"
 #include "codegenerator.h"
 #include "codegenerationpolicy.h"
 #include "classifiercodedocument.h"
 #include "debug_utils.h"
 #include "umlobject.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "codegen_utils.h"
 #include "javaclassifiercodedocument.h"
 #include "javacodegenerationpolicy.h"
