@@ -6,13 +6,13 @@
 
 #include "jswriter.h"
 
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umldoc.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 #include <QRegularExpression>
 #include <QTextStream>
@@ -160,7 +160,7 @@ void JSWriter::writeClass(UMLClassifier *c)
     js << m_endl;
 
     //operations
-    UMLOperationList ops(c->getOpList());
+    UMLOperationList ops(c->getOperationsList());
     writeOperations(classname, &ops, js);
 
     js << m_endl;
@@ -234,7 +234,7 @@ void JSWriter::writeOperations(QString classname, UMLOperationList *opList, QTex
 {
     for (UMLOperation* op :   *opList)
     {
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->doc().isEmpty();
         for (UMLAttribute* at :  atl)
