@@ -8,13 +8,13 @@
 
 #include "php5writer.h"
 
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umldoc.h"
-#include "uml.h"  // only needed for log{Warn,Error}
+#include "umlapp.h"  // only needed for log{Warn,Error}
 
 #include <QRegularExpression>
 #include <QTextStream>
@@ -3158,7 +3158,7 @@ void Php5Writer::writeOperations(UMLClassifier *c, QTextStream &php)
     bool generateErrorStub = false;
 
     //sort operations by scope first and see if there are abstract methods
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     for(UMLOperation *op : opl) {
         switch(op->visibility()) {
           case Uml::Visibility::Public:
@@ -3209,7 +3209,7 @@ void Php5Writer::writeOperations(UMLClassifier *c, QTextStream &php)
             if (real == c)
                 continue;
 
-            UMLOperationList opl(real->getOpList());
+            UMLOperationList opl(real->getOperationsList());
             for(UMLOperation *op : opl) {
                 opreal.append(op);
             }
@@ -3234,7 +3234,7 @@ void Php5Writer::writeOperations(const QString & classname, UMLOperationList &op
 {
     Q_UNUSED(classname);
     for(UMLOperation *op : opList) {
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
 
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->doc().isEmpty();
