@@ -7,13 +7,13 @@
 
 #include "phpwriter.h"
 
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umldoc.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 #include <QRegularExpression>
 #include <QTextStream>
@@ -3146,7 +3146,7 @@ void PhpWriter::writeOperations(UMLClassifier *c, QTextStream &php)
     UMLOperationList oppub, opprot, oppriv;
 
     //sort operations by scope first and see if there are abstract methods
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     for(UMLOperation *op : opl) {
         switch(op->visibility()) {
           case Uml::Visibility::Public:
@@ -3194,7 +3194,7 @@ void PhpWriter::writeOperations(const QString& classname,
 {
     Q_UNUSED(classname);
     for(UMLOperation* op : opList) {
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->doc().isEmpty();
         for(UMLAttribute* at : atl)
