@@ -9,7 +9,7 @@
 #include "rubycodeaccessormethod.h"
 
 // local includes
-#include "attribute.h"
+#include "umlattribute.h"
 #include "codegenerator.h"
 #include "classifiercodedocument.h"
 #include "codegen_utils.h"
@@ -21,7 +21,7 @@
 #include "rubycodedocumentation.h"
 #include "umlobject.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // qt includes
 #include <QRegularExpression>
