@@ -7,17 +7,16 @@
 
 #include "rubywriter.h"
 
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umldoc.h"
 #include "umlattributelist.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 #include <KLocalizedString>
-#include <KMessageBox>
 
 #include <QFile>
 #include <QRegularExpression>
@@ -177,7 +176,7 @@ void RubyWriter::writeOperations(UMLClassifier *c, QTextStream &h)
     UMLOperationList oppub, opprot, oppriv;
 
     //sort operations by scope first and see if there are abstract methods
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     for(UMLOperation *op : opl) {
         switch(op->visibility()) {
         case Uml::Visibility::Public:
@@ -259,7 +258,7 @@ void RubyWriter::writeOperations(const QString &classname, const UMLOperationLis
         methodName.remove(QStringLiteral("operator "));
         methodName = methodName.mid(0, 1).toLower() + methodName.mid(1);
 
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
         // Always write out the docs for ruby as the type of the
         // arguments and return value of the methods is useful
         bool writeDoc = true;
