@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef MYSQLWRITER_H
@@ -28,7 +28,7 @@ public:
 
     Uml::ProgrammingLanguage::Enum language() const;
 
-    QStringList defaultDatatypes();
+    QStringList defaultDatatypes() const;
 
     void printForeignKeyConstraints(QTextStream& sql, UMLClassifierListItemList constrList);
     void printCheckConstraints(QTextStream& sql, UMLClassifierListItemList constrList);
