@@ -9,18 +9,18 @@
 #include "tclwriter.h"
 
 // app includes
-#include "association.h"
-#include "classifier.h"
-#include "classifierlistitem.h"
+#include "umlassociation.h"
+#include "umlclassifier.h"
+#include "umlclassifierlistitem.h"
 #include "codegen_utils.h"
 #include "debug_utils.h"
 #include "model_utils.h"
-#include "operation.h"
-#include "template.h"
+#include "umloperation.h"
+#include "umltemplate.h"
 #include "umltemplatelist.h"
 #include "umlclassifierlistitemlist.h"
 #include "umldoc.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 // qt includes
 #include <QFile>
@@ -678,7 +678,7 @@ void TclWriter::writeOperationHeader(UMLClassifier * c, Uml::Visibility::Enum pe
     int j;
 
     //sort operations by scope first and see if there are abstract methods
-    UMLOperationList inputlist = c->getOpList();
+    UMLOperationList inputlist = c->getOperationsList();
     for(UMLOperation * op : inputlist) {
         switch (op->visibility()) {
         case Uml::Visibility::Public:
@@ -721,7 +721,7 @@ void TclWriter::writeOperationHeader(UMLClassifier * c, Uml::Visibility::Enum pe
             code = scope + QStringLiteral(" method ") + name + QStringLiteral(" {");
         }
         // method parameters
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
         j = 0;
         for(UMLAttribute* at : atl) {
             QString typeName = fixTypeName(at->getTypeName());
@@ -753,7 +753,7 @@ void TclWriter::writeOperationSource(UMLClassifier * c, Uml::Visibility::Enum pe
     int j;
 
     //sort operations by scope first and see if there are abstract methods
-    UMLOperationList inputlist = c->getOpList();
+    UMLOperationList inputlist = c->getOperationsList();
     for(UMLOperation * op : inputlist) {
         switch (op->visibility()) {
         case Uml::Visibility::Public:
@@ -786,7 +786,7 @@ void TclWriter::writeOperationSource(UMLClassifier * c, Uml::Visibility::Enum pe
         writeComm(name);
         code = QStringLiteral("body ") + name + QStringLiteral(" {");
         // parameters
-        UMLAttributeList atl = op->getParmList();
+        UMLAttributeList atl = op->getParameterList();
         j = 0;
         for(UMLAttribute* at : atl) {
             QString atName = cleanName(at->name());
