@@ -9,9 +9,10 @@
 #include "xmlelementcodeblock.h"
 
 // local includes
-#include "attribute.h"
+#include "debug_utils.h"
+#include "umlattribute.h"
 #include "codedocument.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "xmlcodecomment.h"
 
 // qt includes
