@@ -17,7 +17,7 @@
 #include "debug_utils.h"
 #include "defaultcodegenpolicypage.h"
 #include "model_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 
 //kde includes
@@ -115,7 +115,7 @@ void CodeGenStatusPage::generateCode()
         for (int row = 0; row < ui_tableWidgetStatus->rowCount(); ++row) {
             QTableWidgetItem* item = ui_tableWidgetStatus->item(row, 0);
             UMLClassifier *classifier = doc->findUMLClassifier(item->text());
-            if (classifier == 0) {
+            if (classifier == nullptr) {
                 logError1("CodeGenStatusPage::generateCode: Could not find classifier %1 "
                           "(not included in generated code)", item->text());
                 continue;
@@ -126,7 +126,7 @@ void CodeGenStatusPage::generateCode()
 
         m_generationDone = true;
         setFinalPage(true);
-        emit completeChanged();
+        Q_EMIT completeChanged();
     }
 }
 
