@@ -9,8 +9,8 @@
 // app includes
 #define DBG_SRC QStringLiteral("ClassImport")
 #include "debug_utils.h"
-#include "folder.h"
-#include "uml.h"
+#include "umlfolder.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "idlimport.h"
 #include "pythonimport.h"
