@@ -7,25 +7,24 @@
 #include "import_utils.h"
 
 // app includes
-#include "association.h"
-#include "artifact.h"
-#include "classifier.h"
-#include "datatype.h"
+#include "umlassociation.h"
+#include "umlartifact.h"
+#include "umlclassifier.h"
+#include "umldatatype.h"
 #define DBG_SRC QStringLiteral("Import_Utils")
 #include "debug_utils.h"
-#include "folder.h"
-#include "enum.h"
+#include "umlfolder.h"
+#include "umlenum.h"
 #include "object_factory.h"
-#include "operation.h"
-#include "package.h"
-#include "template.h"
-#include "uml.h"
+#include "umloperation.h"
+#include "umlpackage.h"
+#include "umltemplate.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umllistview.h"
 #include "umlobject.h"
 
 // kde includes
-#include <KMessageBox>
 #include <KLocalizedString>
 
 // qt includes
@@ -265,7 +264,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
             QStringList components;
             QString scopeSeparator = UMLApp::app()->activeLanguageScopeSeparator();
             if (typeName.contains(scopeSeparator)) {
-                components = typeName.split(scopeSeparator, QString::SkipEmptyParts);
+                components = typeName.split(scopeSeparator, Qt::SkipEmptyParts);
             } else if (typeName.contains(QStringLiteral("..."))) {
                 // Java variable length arguments
                 type = UMLObject::ot_Datatype;
@@ -564,7 +563,7 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
         op->setDoc(strippedComment);
     }
 
-    UMLAttributeList params = op->getParmList();
+    UMLAttributeList params = op->getParameterList();
     UMLOperation *exist = klass->checkOperationSignature(op->name(), params);
     if (exist) {
         // copy contents to existing operation
@@ -573,7 +572,7 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
         exist->setAbstract(isAbstract);
         if (! strippedComment.isEmpty())
             exist->setDoc(strippedComment);
-        UMLAttributeList exParams = exist->getParmList();
+        UMLAttributeList exParams = exist->getParameterList();
         for (UMLAttributeListIt it(params), exIt(exParams) ; it.hasNext() ;) {
             UMLAttribute *param = it.next(), *exParam = exIt.next();
             exParam->setName(param->name());
@@ -609,7 +608,7 @@ UMLAttribute* addMethodParameter(UMLOperation *method,
         bPutAtGlobalScope = false;
     }
     UMLAttribute *attr = Object_Factory::createAttribute(method, name, typeObj);
-    method->addParm(attr);
+    method->addParameter(attr);
     return attr;
 }
 
