@@ -8,14 +8,14 @@
 
 // app includes
 #include "associationwidget.h"
-#include "association.h"
+#include "umlassociation.h"
 #define DBG_SRC QStringLiteral("Diagram_Utils")
 #include "debug_utils.h"
 #include "import_utils.h"
 #include "messagewidget.h"
 #include "object_factory.h"
 #include "objectwidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlview.h"
 #include "umlobject.h"
@@ -503,7 +503,9 @@ bool importGraph(const QString &fileName, UMLScene *scene)
 
     QStringList lines;
     QTextStream in(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     in.setCodec("UTF-8");
+#endif
     while (!in.atEnd()) {
         lines.append(in.readLine());
     }
