@@ -28,7 +28,7 @@ class ExportAllViewsDialog : public SinglePageDialogBase, private Ui::ExportAllV
 
 public:
 
-    explicit ExportAllViewsDialog(QWidget* parent = 0, const char* name = 0);
+    explicit ExportAllViewsDialog(QWidget  *parent = nullptr, const char *name = nullptr);
 
     ~ExportAllViewsDialog();
 
@@ -36,7 +36,7 @@ private:
     ImageTypeWidget* m_imageType;  ///< The image type selected.
     ResolutionWidget* m_imageResolution;  ///< The image resolution selected.
 
-protected slots:
+protected Q_SLOTS:
 
     friend class UMLViewImageExporterAll;
 
