@@ -8,9 +8,9 @@
 #include "stereoattributedialog.h"
 
 // app includes
-#include "stereotype.h"
+#include "umlstereotype.h"
 #include "umldoc.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "dialog_utils.h"
 #include "debug_utils.h"
 
@@ -19,7 +19,6 @@
 #include <kcombobox.h>
 #include <kcompletion.h>
 #include <KLocalizedString>
-#include <KMessageBox>
 
 // qt includes
 #include <QGridLayout>
