@@ -17,7 +17,7 @@ class QRadioButton;
 class QLabel;
 class UMLObject;
 class UMLAttribute;
-class KLineEdit;
+class QLineEdit;
 class UMLDatatypeWidget;
 class UMLStereotypeWidget;
 class VisibilityEnumWidget;
@@ -46,16 +46,16 @@ protected:
     QGridLayout * m_pValuesLayout;
     QGroupBox * m_pValuesGB;
     QLabel * m_pNameL, * m_pInitialL;
-    KLineEdit * m_pNameLE, * m_pInitialLE;
+    QLineEdit * m_pNameLE, * m_pInitialLE;
     QCheckBox* m_pStaticCB;
     UMLDatatypeWidget *m_datatypeWidget;
     UMLStereotypeWidget *m_stereotypeWidget;
     QLabel              *m_pTagL [N_STEREOATTRS];
-    KLineEdit           *m_pTagLE[N_STEREOATTRS];
+    QLineEdit           *m_pTagLE[N_STEREOATTRS];
     VisibilityEnumWidget *m_visibilityEnumWidget;
     DocumentationWidget *m_docWidget;
 
-public slots:
+public Q_SLOTS:
     void slotNameChanged(const QString &);
     void slotStereoTextChanged(const QString &);
 };
