@@ -1,18 +1,13 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "umlroledialog.h"
 
 // kde includes
-#include <klocale.h>
+#include <KLocalizedString>
 
 // app includes
 #include "umlrole.h"
@@ -57,4 +52,3 @@ bool UMLRoleDialog::apply()
     return false;
 }
 
-#include "umlroledialog.moc"
