@@ -20,17 +20,17 @@ class ImageTypeWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ImageTypeWidget(const QStringList &imageTypes, const QString &_default, QWidget *parent = 0);
+    explicit ImageTypeWidget(const QStringList &imageTypes, const QString &_default, QWidget *parent = nullptr);
     QString currentType();
 
 private:
     QLabel *m_label;
     KComboBox* m_comboBox;  ///< The image type selected.
 
-signals:
+Q_SIGNALS:
     void currentIndexChanged(const QString &index);
 
-private slots:
+private Q_SLOTS:
     void slotCurrentIndexChanged(const QString &index);
 };
 
