@@ -6,7 +6,7 @@
 #include "visibilityenumwidget.h"
 
 #include "associationwidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umlobject.h"
 
 #include <KLocalizedString>
@@ -18,7 +18,7 @@
 VisibilityEnumWidget::VisibilityEnumWidget(UMLObject *o, QWidget *parent)
     : QWidget(parent),
       m_object(o),
-      m_widget(0),
+      m_widget(nullptr),
       m_role(Uml::RoleType::A)
 {
     Q_ASSERT(o);
@@ -33,7 +33,7 @@ VisibilityEnumWidget::VisibilityEnumWidget(UMLObject *o, QWidget *parent)
 
 VisibilityEnumWidget::VisibilityEnumWidget(AssociationWidget *a, Uml::RoleType::Enum role, QWidget *parent)
     : QWidget(parent),
-      m_object(0),
+      m_object(nullptr),
       m_widget(a),
       m_role(role)
 {
@@ -90,7 +90,7 @@ void VisibilityEnumWidget::init(const QString &title)
     m_box = new QGroupBox(title, this);
     QHBoxLayout* boxlayout = new QHBoxLayout(m_box);
     int margin = fontMetrics().height();
-    boxlayout->setMargin(margin);
+    boxlayout->setContentsMargins(margin, margin, margin, margin);
     QList<Uml::Visibility::Enum> orders;
     orders << Uml::Visibility::Public << Uml::Visibility::Protected << Uml::Visibility::Private << Uml::Visibility::Implementation;
 
