@@ -25,8 +25,8 @@ public:
     typedef QMap<Uml::Visibility::Enum,QString> TextMap;
     typedef QMap<Uml::Visibility::Enum,QRadioButton*> ButtonMap;
 
-    explicit VisibilityEnumWidget(UMLObject *o, QWidget *parent=0);
-    VisibilityEnumWidget(AssociationWidget *a, Uml::RoleType::Enum role, QWidget *parent=0);
+    explicit VisibilityEnumWidget(UMLObject  *o, QWidget *parent= nullptr);
+    VisibilityEnumWidget(AssociationWidget  *a, Uml::RoleType::Enum role, QWidget *parent= nullptr);
     ~VisibilityEnumWidget();
 
     void addToLayout(QVBoxLayout *layout);
