@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2018-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2018-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef DIALOGSPOPUPMENU_H
@@ -38,7 +38,7 @@ public:
     };
 
     DialogsPopupMenu(QWidget *parent, TriggerType type);
-    void insertSubMenuNew(TriggerType type, KMenu *menu = 0);
+    void insertSubMenuNew(TriggerType type);
     static QString toString(TriggerType type);
 };
 
