@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2018-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2018-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef UMLLISTVIEWPOPUPMENU_H
@@ -14,7 +14,7 @@ public:
     UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *item);
 
 protected:
-    void insertSubMenuNew(UMLListViewItem::ListViewType type, KMenu *menu = 0);
+    void insertSubMenuNew(UMLListViewItem::ListViewType type);
     void insertStdItems(bool insertLeadingSeparator = true);
     void insertSubmodelAction();
 };
