@@ -12,20 +12,20 @@
 #include "debug_utils.h"
 #include "umlobject.h"
 #include "umlpackagelist.h"
-#include "uniqueconstraint.h"
-#include "package.h"
-#include "folder.h"
-#include "classifier.h"
-#include "enum.h"
-#include "instance.h"
-#include "entity.h"
-#include "template.h"
-#include "operation.h"
-#include "attribute.h"
-#include "association.h"
+#include "umluniqueconstraint.h"
+#include "umlpackage.h"
+#include "umlfolder.h"
+#include "umlclassifier.h"
+#include "umlenum.h"
+#include "umlinstance.h"
+#include "umlentity.h"
+#include "umltemplate.h"
+#include "umloperation.h"
+#include "umlattribute.h"
+#include "umlassociation.h"
 #include "umlrole.h"
 #include "umldoc.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umllistview.h"
 #include "umllistviewitem.h"
 #include "umlscene.h"
@@ -388,6 +388,7 @@ UMLObject* findUMLObjectRecursive(const UMLObjectList& inList,
                                   UMLObject::ObjectType type /* = ot_UMLObject */)
 {
     for(UMLObject *obj : inList) {
+        uIgnoreZeroPointer(obj);
         if (obj->name() == name && type == obj->baseType())
             return obj;
         const UMLPackage *pkg = obj->asUMLPackage();
