@@ -8,9 +8,9 @@
 // app includes
 #include "umlscene.h"
 #include "umlview.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
-#include "folder.h"
+#include "umlfolder.h"
 
 // kde includes
 #include <KLocalizedString>
