@@ -11,9 +11,7 @@
 
 // qt includes
 #include <QAbstractTableModel>
-#include "stereotype.h"
-
-Q_DECLARE_METATYPE(UMLStereotype*);
+#include "umlstereotype.h"
 
 class StereotypesModel : public QAbstractTableModel
 {
