@@ -7,17 +7,17 @@
 
 #include "refactoringassistant.h"
 
-#include "attribute.h"
+#include "umlattribute.h"
 #include "basictypes.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "classpropertiesdialog.h"
 #include "debug_utils.h"
 #include "object_factory.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umlattributedialog.h"
 #include "umldoc.h"
 #include "umloperationdialog.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -83,7 +83,7 @@ void RefactoringAssistant::refactor(UMLClassifier *obj)
     DEBUG() << "called for " << m_umlObject->name();
 
     m_alreadySeen.clear();
-    addClassifier(obj, 0, true, true, true);
+    addClassifier(obj, nullptr, true, true, true);
     QTreeWidgetItem *item = topLevelItem(0);
     item->setExpanded(true);
     for (int i = 0; i < item->childCount(); ++i) {
@@ -99,13 +99,13 @@ void RefactoringAssistant::refactor(UMLClassifier *obj)
 UMLObject* RefactoringAssistant::findUMLObject(const QTreeWidgetItem *item)
 {
     if (!item) {
-        return 0;
+        return nullptr;
     }
     QTreeWidgetItem *i = const_cast<QTreeWidgetItem*>(item);
     if (m_umlObjectMap.find(i) == m_umlObjectMap.end()) {
         logWarn1("RefactoringAssistant::findUMLObject: Item with text %1 not found in uml map",
                  item->text(0));
-        return 0;
+        return nullptr;
     }
     return m_umlObjectMap[i];
 }
@@ -126,7 +126,7 @@ QTreeWidgetItem* RefactoringAssistant::findListViewItem(const UMLObject *obj)
     }
     logWarn1("RefactoringAssistant::findUMLObject: Object id %1 does not have an item in the tree",
              Uml::ID::toString(obj->id()));
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -326,7 +326,7 @@ void RefactoringAssistant::editProperties()
  */
 void RefactoringAssistant::editProperties(UMLObject *obj)
 {
-    QDialog *dia(0);
+    QDialog *dia(nullptr);
     UMLObject::ObjectType t = obj->baseType();
     if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface) {
         ClassPropertiesDialog *dialog = new ClassPropertiesDialog(this, obj, true);
@@ -500,7 +500,7 @@ void RefactoringAssistant::addBaseClassifier()
 
     //////////////////////   Manually add the classifier to the assistant - would be nicer to do it with
     /////////////////////    a signal, like operations and attributes
-    QTreeWidgetItem *baseFolder = 0;
+    QTreeWidgetItem  *baseFolder = nullptr;
     for (int i = 0; i < item->childCount(); ++i) {
         baseFolder = item->child(i);
         if (!baseFolder) {
@@ -545,7 +545,7 @@ void RefactoringAssistant::addDerivedClassifier()
 
     //////////////////////   Manually add the classifier to the assistant - would be nicer to do it with
     /////////////////////    a signal, like operations and attributes
-    QTreeWidgetItem *derivedFolder = 0;
+    QTreeWidgetItem  *derivedFolder = nullptr;
     for (int i = 0; i < item->childCount(); ++i) {
         derivedFolder = item->child(i);
         if (!derivedFolder) {
@@ -667,7 +667,7 @@ void RefactoringAssistant::addClassifier(UMLClassifier *classifier, QTreeWidgetI
     attsFolder->setIcon(0, Icon_Utils::SmallIcon(Icon_Utils::it_Folder_Orange));
     attsFolder->setExpanded(true);
     UMLAttributeList atts(classifier->getAttributeList());
-    foreach(UMLAttribute* att, atts) {
+    for(UMLAttribute *att : atts) {
         attributeAdded(att);
     }
 
@@ -682,8 +682,8 @@ void RefactoringAssistant::addClassifier(UMLClassifier *classifier, QTreeWidgetI
     QTreeWidgetItem *opsFolder = new QTreeWidgetItem(classifierItem, itemTextOp);
     opsFolder->setIcon(0, Icon_Utils::SmallIcon(Icon_Utils::it_Folder_Orange));
     opsFolder->setExpanded(true);
-    UMLOperationList ops(classifier->getOpList());
-    foreach(UMLOperation* op, ops) {
+    UMLOperationList ops(classifier->getOperationsList());
+    for(UMLOperation *op : ops) {
         operationAdded(op);
     }
 
@@ -691,7 +691,7 @@ void RefactoringAssistant::addClassifier(UMLClassifier *classifier, QTreeWidgetI
         QTreeWidgetItem *superFolder = new QTreeWidgetItem(classifierItem, QStringList(i18n("Base Classifiers")));
         superFolder->setExpanded(true);
         UMLClassifierList super = classifier->findSuperClassConcepts();
-        foreach(UMLClassifier* cl, super) {
+        for(UMLClassifier *cl : super) {
             item = new QTreeWidgetItem(superFolder, QStringList(cl->name()));
             item->setIcon(0, Icon_Utils::SmallIcon(Icon_Utils::it_Generalisation));
             item->setExpanded(true);
@@ -710,7 +710,7 @@ void RefactoringAssistant::addClassifier(UMLClassifier *classifier, QTreeWidgetI
         QTreeWidgetItem *derivedFolder = new QTreeWidgetItem(classifierItem, QStringList(i18n("Derived Classifiers")));
         derivedFolder->setExpanded(true);
         UMLClassifierList derived = classifier->findSubClassConcepts();
-        foreach(UMLClassifier* d, derived) {
+        for(UMLClassifier *d : derived) {
             item = new QTreeWidgetItem(derivedFolder, QStringList(d->name()));
             item->setIcon(0, Icon_Utils::SmallIcon(Icon_Utils::it_Uniassociation));
             item->setExpanded(true);
@@ -817,11 +817,11 @@ DEBUG() << "acceptProposedAction";  //:TODO:fischer
     if (t == UMLObject::ot_Operation) {
         DEBUG() << "Moving operation";
         UMLOperation *op = movingObject->asUMLOperation();
-        if (newClassifier->checkOperationSignature(op->name(), op->getParmList())) {
+        if (newClassifier->checkOperationSignature(op->name(), op->getParameterList())) {
             QString msg = i18n("An operation with that signature already exists in %1.\n", newClassifier->name())
                           +
                           i18n("Choose a different name or parameter list.");
-            KMessageBox::error(this, msg, i18n("Operation Name Invalid"), 0);
+            KMessageBox::error(this, msg, i18n("Operation Name Invalid"));
             return;
         }
         UMLOperation* newOp = op->clone()->asUMLOperation();
@@ -842,7 +842,7 @@ DEBUG() << "acceptProposedAction";  //:TODO:fischer
             QString msg = i18n("An attribute with that name already exists in %1.\n", newClassifier->name())
                           +
                           i18n("Choose a different name.");
-            KMessageBox::error(this, msg, i18n("Attribute Name Invalid"), 0);
+            KMessageBox::error(this, msg, i18n("Attribute Name Invalid"));
             return;
         }
         UMLAttribute* newAtt = att->clone()->asUMLAttribute();
@@ -856,7 +856,7 @@ DEBUG() << "acceptProposedAction";  //:TODO:fischer
         newClassifier->addAttribute(newAtt);
         m_doc->signalUMLObjectCreated(newAtt);  //:TODO: really?
     }
-//    emit moved();
+//    Q_EMIT moved();
     refactor(m_umlObject);  //:TODO:fischer
 }
 
