@@ -8,17 +8,17 @@
 
 // app includes
 #include "assocrules.h"
-#include "association.h"
+#include "umlassociation.h"
 #include "associationline.h"
 #include "associationwidget.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "classifierwidget.h"
 #include "cmds/widget/cmdcreatewidget.h"
 #include "floatingtextwidget.h"
 #include "debug_utils.h"
-#include "folder.h"
+#include "umlfolder.h"
 #include "model_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlscene.h"
