@@ -6,10 +6,9 @@
 #include "umlappprivate.h"
 
 #define DBG_SRC QStringLiteral("UMLAppPrivate")
+#include "compressionhelper.h"
 #include "debug_utils.h"
 
-#include <KFilterDev>
-
 DEBUG_REGISTER(UMLAppPrivate)
 
 /**
@@ -69,7 +68,7 @@ QString UMLAppPrivate::readWelcomeFile(const QString &file)
 {
     QString html;
     if (file.endsWith(QStringLiteral(".cache.bz2"))) {
-        QIODevice *d =  KFilterDev::deviceForFile(file);
+        QIODevice *d =  CompressionHelper::deviceForFile(file);
         if (!d->open(QIODevice::ReadOnly)) {
             uError() << "could not open archive " << file;
             return QString();
@@ -155,7 +154,11 @@ bool UMLAppPrivate::openFileInEditor(const QUrl &file, int startCursor, int endC
     view->document()->setReadWrite(false);
     if (startCursor != endCursor)
         view->setCursorPosition(KTextEditor::Cursor(startCursor, endCursor));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KTextEditor::ConfigInterface *iface = qobject_cast<KTextEditor::ConfigInterface*>(view);
+#else
+    KTextEditor::View *iface = view;
+#endif
     if(iface)
         iface->setConfigValue(QString::fromLatin1("line-numbers"), true);
 
