@@ -9,16 +9,16 @@
 // app includes
 #include "classpropertiesdialog.h"
 #include "debug_utils.h"
-#include "enumliteral.h"
+#include "umlenumliteral.h"
 #include "uniqueid.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umllistview.h"
 #include "umlobjectprivate.h"
 #include "models/objectsmodel.h"
-#include "package.h"
-#include "folder.h"
-#include "stereotype.h"
+#include "umlpackage.h"
+#include "umlfolder.h"
+#include "umlstereotype.h"
 #include "object_factory.h"
 #include "model_utils.h"
 #include "import_utils.h"
@@ -1387,30 +1387,30 @@ QDebug operator<<(QDebug out, const UMLObject& obj)
 }
 
 //only required for getting types
-#include "actor.h"
-#include "artifact.h"
-#include "association.h"
-#include "attribute.h"
+#include "umlactor.h"
+#include "umlartifact.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
 #include "umlcanvasobject.h"
-#include "category.h"
-#include "checkconstraint.h"
-#include "classifier.h"
-#include "component.h"
-#include "datatype.h"
-#include "entity.h"
-#include "entityattribute.h"
-#include "entityconstraint.h"
-#include "enum.h"
-#include "foreignkeyconstraint.h"
-#include "instance.h"
-#include "instanceattribute.h"
-#include "node.h"
-#include "operation.h"
-#include "port.h"
+#include "umlcategory.h"
+#include "umlcheckconstraint.h"
+#include "umlclassifier.h"
+#include "umlcomponent.h"
+#include "umldatatype.h"
+#include "umlentity.h"
+#include "umlentityattribute.h"
+#include "umlentityconstraint.h"
+#include "umlenum.h"
+#include "umlforeignkeyconstraint.h"
+#include "umlinstance.h"
+#include "umlinstanceattribute.h"
+#include "umlnode.h"
+#include "umloperation.h"
+#include "umlport.h"
 #include "umlrole.h"
-#include "template.h"
-#include "uniqueconstraint.h"
-#include "usecase.h"
+#include "umltemplate.h"
+#include "umluniqueconstraint.h"
+#include "umlusecase.h"
 
 UMLActor                * UMLObject::asUMLActor()                { return dynamic_cast<UMLActor*>(this); }
 UMLArtifact             * UMLObject::asUMLArtifact()             { return dynamic_cast<UMLArtifact*>(this); }
