@@ -7,13 +7,13 @@
 #include "componentwidget.h"
 
 // app includes
-#include "component.h"
+#include "umlcomponent.h"
 #include "debug_utils.h"
 #include "umlscene.h"
 #include "umlview.h"
 #include "optionstate.h"
 #include "umldoc.h"
-#include "package.h"
+#include "umlpackage.h"
 #include "portwidget.h"
 
 // qt includes
