@@ -7,20 +7,20 @@
 #include "entitywidget.h"
 
 // app includes
-#include "classifier.h"
-#include "classifierlistitem.h"
+#include "umlclassifier.h"
+#include "umlclassifierlistitem.h"
 #include "debug_utils.h"
-#include "entity.h"
-#include "entityattribute.h"
-#include "foreignkeyconstraint.h"
+#include "umlentity.h"
+#include "umlentityattribute.h"
+#include "umlforeignkeyconstraint.h"
 #include "listpopupmenu.h"
 #include "object_factory.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umlclassifierlistitemlist.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
-#include "uniqueconstraint.h"
+#include "umluniqueconstraint.h"
 
 // qt includes
 #include <QXmlStreamWriter>
