@@ -7,11 +7,11 @@
 #include "testclassifier.h"
 
 // app include
-#include "uml.h"
-#include "association.h"
-#include "classifier.h"
-#include "datatype.h"
-#include "operation.h"
+#include "umlapp.h"
+#include "umlassociation.h"
+#include "umlclassifier.h"
+#include "umldatatype.h"
+#include "umloperation.h"
 #include "model_utils.h"
 
 //-----------------------------------------------------------------------------
@@ -166,11 +166,11 @@ void TEST_classifier::test_findOperations()
     UMLClassifier c(QStringLiteral("Test A"), Uml::ID::None);
     UMLOperation o1(nullptr, QStringLiteral("testop1"));
     c.addOperation(&o1);
-    int num1 = c.getOpList().count();
+    int num1 = c.getOperationsList().count();
     QCOMPARE(num1, 1);
     UMLOperation o2(nullptr, QStringLiteral("testop2"));
     c.addOperation(&o2);
-    int num2 = c.getOpList().count();
+    int num2 = c.getOperationsList().count();
     QCOMPARE(num2, 2);
     QCOMPARE(c.findOperations(QStringLiteral("testop1")).count(), 1);
     QCOMPARE(c.findOperations(QStringLiteral("testop2")).count(), 1);
@@ -195,12 +195,12 @@ void TEST_classifier::test_findOperation()
     UMLOperation o1(nullptr, QStringLiteral("testop1"));
     UMLAttribute a1(nullptr, QStringLiteral("aParam"));
     a1.setTypeName(QStringLiteral("int"));
-    o1.addParm(&a1);
+    o1.addParameter(&a1);
     c.addOperation(&o1);
     UMLOperation o2(nullptr, QStringLiteral("testop1"));
     UMLAttribute a2(nullptr, QStringLiteral("aParam"));
     a2.setTypeName(QStringLiteral("double"));
-    o2.addParm(&a2);
+    o2.addParameter(&a2);
     c.addOperation(&o2);
     Model_Utils::NameAndType_List searchTypes;
     // first function
