@@ -12,17 +12,17 @@
 #include "umllistviewpopupmenu.h"
 #include "umlscenepopupmenu.h"
 
-#include "category.h"
-#include "entity.h"
-#include "classifier.h"
-#include "instance.h"
+#include "umlcategory.h"
+#include "umlentity.h"
+#include "umlclassifier.h"
+#include "umlinstance.h"
 
 #include "associationwidget.h"
 #include "categorywidget.h"
 #include "classifierwidget.h"
 #include "entitywidget.h"
 
-#include "folder.h"
+#include "umlfolder.h"
 #include "umllistview.h"
 #include "umlscene.h"
 #include "umlview.h"
