@@ -13,7 +13,7 @@ class TestOptionState : public TestBase
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void test_create();
     void test_saveAndLoad();
 };
