@@ -5,12 +5,15 @@
 */
 
 // app includes
-#include "association.h"
-#include "stereotype.h"
-#include "uml.h"
+#include "umlassociation.h"
+#include "umlstereotype.h"
+#include "umlapp.h"
 #include "umlrole.h"
 #include "umlroledialog.h"
 
+// KDE includes
+#include <KLocalizedString>
+
 // qt includes
 #include <QApplication>
 #include <QtDebug>
@@ -18,6 +21,7 @@
 int main(int argc, char **argv)
 {
     QApplication a(argc, argv);
+    KLocalizedString::setApplicationDomain("umbrello");
     UMLApp app;
     app.setup();
 
